@@ -37,7 +37,7 @@ class Validator:
     ``instance``: A file path to a *YAML* representation of a `json` representing the instance to validate.
 
     Raises:
-      ``laboro.error.Error``: Whenever the schema or the instance file can't be loaded or are not valid *YAML* files. Error is also raised when the given ``schema`` is not a valid `jsonschema` or when ``instance`` can not validate against the given ``schema`.
+      ``laboro.error.Error``: Whenever the schema or the instance file can't be loaded or are not valid *YAML* files. Error is also raised when the given ``schema`` is not a valid `jsonschema` or when ``instance`` can not validate against the given ``schema``.
     """
     try:
       schema_yml = self._load_file(schema)
@@ -64,7 +64,7 @@ class Validator:
       schema: A dict representing the instance to validate.
 
     Raises:
-      ``laboro.error.Error``: Whenever the schema file can't be loaded or is not valid *YAML* files. Error is also raised when the given ``schema`` is not a valid `jsonschema` or when ``data`` can not validate against the given ``schema`.
+      ``laboro.error.Error``: Whenever the schema file can't be loaded or is not valid *YAML* files. Error is also raised when the given ``schema`` is not a valid `jsonschema` or when ``data`` can not validate against the given ``schema``.
     """
     try:
       schema_yml = self._load_file(schema)
@@ -87,30 +87,37 @@ class Validator:
     """
     try:
       validate(instance=args, schema=method)
-      if isinstance(args, dict):
-        if self._validate_required(args, method):
-          for arg, value in args.items():
-            if arg in [arg["name"] for arg in method["args"]]:
-              self._validate_type(arg, value, method)
-              self._validate_implied(arg, args, method)
-              self._validate_excluded(arg, args, method)
-            else:
-              msg = {"type": "UnknownArgError",
-                     "message": f"Unknown argument: {arg}"}
-              logging.critical(f"[{msg['type']}] {msg['message']}")
-              raise LaboroError(f"[{msg['type']}] {msg['message']}")
-          return True
-        msg = "[MissingRequiredArgError] Missing required argument."
-        logging.critical(msg)
-        raise LaboroError(msg)
-      msg = f"[ModuleArgError]: Expected a dict as args, received {type(args)}"
-      logging.critical(msg)
-      raise LaboroError(msg)
     except ValidationError as err:
       err_msg = str(err).split("\n")[0]
       msg = f"[InvalidSpecError] {err_msg}"
       logging.critical(msg)
       raise LaboroError(msg) from err
+    if not isinstance(args, dict):
+      msg = f"[ModuleArgError]: Expected dict, received {type(args)}"
+      logging.critical(msg)
+      raise LaboroError(msg)
+    if "args" not in method:
+      if len(args) > 0:
+        msg = {"type": "TooManyArgsError",
+               "message": f"Method does not accept args: {method['name']}"}
+        logging.critical(f"[{msg['type']}] {msg['message']}")
+        raise LaboroError(f"[{msg['type']}] {msg['message']}")
+      else:
+        return
+    if not self._validate_required(args, method):
+      msg = "[MissingRequiredArgError] Missing required argument."
+      logging.critical(msg)
+      raise LaboroError(msg)
+    for arg, value in args.items():
+      if arg in [arg["name"] for arg in method["args"]]:
+        self._validate_type(arg, value, method)
+        self._validate_implied(arg, args, method)
+        self._validate_excluded(arg, args, method)
+      else:
+        msg = {"type": "UnknownArgError",
+               "message": f"Unknown argument: {arg}"}
+        logging.critical(f"[{msg['type']}] {msg['message']}")
+        raise LaboroError(f"[{msg['type']}] {msg['message']}")
 
   def validate_obj_args(self, specification, args):
     """Validate the instantiation arguments against the object specification.
@@ -123,32 +130,39 @@ class Validator:
       ``laboro.error.LaboroError``: When the given ``args`` does not validate against the specification.
     """
     try:
-      specification_yml = self._load_file(specification)
-      validate(instance=args, schema=specification_yml)
-      if isinstance(args, dict):
-        if self._validate_required(args, specification_yml):
-          for arg, value in args.items():
-            if arg in [arg["name"] for arg in specification_yml["args"]]:
-              self._validate_type(arg, value, specification_yml)
-              self._validate_implied(arg, args, specification_yml)
-              self._validate_excluded(arg, args, specification_yml)
-            else:
-              msg = {"type": "UnknownArgError",
-                     "message": f"Unknown argument: {arg}"}
-              logging.critical(f"[{msg['type']}] {msg['message']}")
-              raise LaboroError(f"[{msg['type']}] {msg['message']}")
-          return True
-        msg = "[MissingRequiredArgError] Missing required argument."
-        logging.critical(msg)
-        raise LaboroError(msg)
-      msg = f"[ModuleArgError]: Expected a dict as args, received {type(args)}"
-      logging.critical(msg)
-      raise LaboroError(msg)
+      obj = self._load_file(specification)
+      validate(instance=args, schema=obj)
     except ValidationError as err:
       err_msg = str(err).split("\n")[0]
       msg = f"[InvalidSpecError] {err_msg}"
       logging.critical(msg)
       raise LaboroError(msg) from err
+    if not isinstance(args, dict):
+      msg = f"[ModuleArgError]: Expected a dict as args, received {type(args)}"
+      logging.critical(msg)
+      raise LaboroError(msg)
+    if "args" not in obj:
+      if len(args) > 0:
+        msg = {"type": "TooManyArgsError",
+               "message": f"Object constructor does not accept args: {obj['class']}"}
+        logging.critical(f"[{msg['type']}] {msg['message']}")
+        raise LaboroError(f"[{msg['type']}] {msg['message']}")
+      else:
+        return
+    if not self._validate_required(args, obj):
+      msg = "[MissingRequiredArgError] Missing required argument."
+      logging.critical(msg)
+      raise LaboroError(msg)
+    for arg, value in args.items():
+      if arg in [arg["name"] for arg in obj["args"]]:
+        self._validate_type(arg, value, obj)
+        self._validate_implied(arg, args, obj)
+        self._validate_excluded(arg, args, obj)
+      else:
+        msg = {"type": "UnknownArgError",
+               "message": f"Unknown argument: {arg}"}
+        logging.critical(f"[{msg['type']}] {msg['message']}")
+        raise LaboroError(f"[{msg['type']}] {msg['message']}")
 
   def _validate_required(self, arguments, specification):
     required = sorted([arg["name"] for arg in list(filter(lambda arg: arg["required"], specification["args"]))])
