@@ -1,4 +1,3 @@
-import re
 import uuid
 import logging
 from laboro.logic.processor import Processor
@@ -49,15 +48,13 @@ class Workflow:
   def _get_iterable(self, obj):
     return Processor().process(self.ctx, obj["loop"])
 
-  # def _interpolated(self, args):
-  #   for key, value in args.items():
-  #     args[key] = Processor().process_arg(self.ctx, str(value))
-
-  def _interpolate(self, args):
-    interpolated = args.copy()
-    for key, value in interpolated.items():
-      interpolated[key] = Processor().process_arg(self.ctx, str(value))
-    return interpolated
+  def _interpolate(self, obj):
+    if "args" in obj:
+      interpolated = obj["args"].copy()
+      for key, value in interpolated.items():
+        interpolated[key] = Processor().process_arg(self.ctx, str(value))
+      return interpolated
+    return dict()
 
   def _do_step(self, step):
     step_name = step['name']
@@ -86,10 +83,8 @@ class Workflow:
     logging.getLogger().log_section("STEP", f"{step_name} / { action_name}")
     module = action["object"]["module"]
     cls = action["object"]["class"]
-    cls_args = dict()
+    cls_args = self._interpolate(action["object"])
     if action["object"]["instantiate"]:
-      cls_args = action["object"]["args"] or dict()
-      cls_args = self._interpolate(cls_args)
       instance = self.ctx.instantiate(module, cls, cls_args)
       self.ctx.put(instance_name, instance)
     else:
@@ -110,15 +105,14 @@ class Workflow:
       msg = f"Skipping {action_name} / {instance_name}.{method_name}: Condition not met: {method['when']}"
       logging.getLogger().log_section("ACTION", msg, level=logging.WARNING)
       return
-    method_args = method["args"] or dict()
-    method_args = self._interpolate(method_args)
+    method_args = self._interpolate(method)
     logging.getLogger().log_section("ACTION",
                                     f"{action_name} / {instance_name}.{method_name}")
     self.ctx.register_method_secrets(instance,
                                      method_name,
                                      method_args)
     result = getattr(instance, method_name)(**method_args)
-    if method["output"] is not None:
+    if "output" in method:
       self.ctx.put(method["output"], result)
 
   def run(self):
